==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/listeners/NavigationTreeControlsActionListener.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation.listeners;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.List;

import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.model.NavigationTableModel;
import net.sourceforge.atunes.gui.views.panels.NavigationPanel;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerState.ViewMode;
import net.sourceforge.atunes.kernel.handlers.PlayListHandler;
import net.sourceforge.atunes.model.AudioObject;

/**
 * The listener interface for receiving navigationTreeControlsAction events.
 */
public class NavigationTreeControlsActionListener implements ActionListener {

	/** The controller. */
	private NavigationController controller;

	/** The panel. */
	private NavigationPanel panel;

	/**
	 * Instantiates a new navigation tree controls action listener.
	 * 
	 * @param controller
	 *            the controller
	 * @param panel
	 *            the panel
	 */
	public NavigationTreeControlsActionListener(NavigationController controller, NavigationPanel panel) {
		this.controller = controller;
		this.panel = panel;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == panel.getCollapseTree()) {
			GuiUtils.collapseTree(panel.getRepositoryTree());
			GuiUtils.collapseTree(panel.getFavoritesTree());
			GuiUtils.collapseTree(panel.getDeviceTree());
		} else if (e.getSource() == panel.getExpandTree()) {
			GuiUtils.expandTree(panel.getRepositoryTree());
			GuiUtils.expandTree(panel.getFavoritesTree());
			GuiUtils.expandTree(panel.getDeviceTree());
		} else if (e.getSource() == panel.getFilterTextField()) {
			String text = panel.getFilterTextField().getText();
			if (text.equals(""))
				text = null;
			controller.getState().setCurrentFilter(text);
			controller.refreshTreeContent();
		} else if (e.getSource() == panel.getClearFilterButton()) {
			panel.getFilterTextField().setText("");
			controller.getState().setCurrentFilter(null);
			controller.refreshTreeContent();
		} else if (e.getSource() == panel.getAddToPlayList()) {
			List<AudioObject> songs = ((NavigationTableModel) panel.getNavigationTable().getModel()).getSongs();
			PlayListHandler.getInstance().addToPlayList(songs);
		} else if (e.getSource() == panel.getShowArtist()) {
			if (controller.getState().getViewMode() != ViewMode.ARTIST) {
				controller.getState().setViewMode(ViewMode.ARTIST);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowAlbum()) {
			if (controller.getState().getViewMode() != ViewMode.ALBUM) {
				controller.getState().setViewMode(ViewMode.ALBUM);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowGenre()) {
			if (controller.getState().getViewMode() != ViewMode.GENRE) {
				controller.getState().setViewMode(ViewMode.GENRE);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowFolder()) {
			if (controller.getState().getViewMode() != ViewMode.FOLDER) {
				controller.getState().setViewMode(ViewMode.FOLDER);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		}
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/listeners/NavigationTreeControlsActionListener.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation.listeners;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import net.sourceforge.atunes.gui.GuiUtils;
import net.sourceforge.atunes.gui.views.panels.NavigationPanel;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationController;
import net.sourceforge.atunes.kernel.controllers.navigation.NavigationControllerState.ViewMode;

/**
 * The listener interface for receiving navigationTreeControlsAction events.
 */
public class NavigationTreeControlsActionListener implements ActionListener {

	/** The controller. */
	private NavigationController controller;

	/** The panel. */
	private NavigationPanel panel;

	/**
	 * Instantiates a new navigation tree controls action listener.
	 * 
	 * @param controller
	 *            the controller
	 * @param panel
	 *            the panel
	 */
	public NavigationTreeControlsActionListener(NavigationController controller, NavigationPanel panel) {
		this.controller = controller;
		this.panel = panel;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == panel.getCollapseTree()) {
			GuiUtils.collapseTree(panel.getRepositoryTree());
			GuiUtils.collapseTree(panel.getFavoritesTree());
			GuiUtils.collapseTree(panel.getDeviceTree());
		} else if (e.getSource() == panel.getExpandTree()) {
			GuiUtils.expandTree(panel.getRepositoryTree());
			GuiUtils.expandTree(panel.getFavoritesTree());
			GuiUtils.expandTree(panel.getDeviceTree());
		} else if (e.getSource() == panel.getFilterTextField()) {
			String text = panel.getFilterTextField().getText();
			if (text.equals("")) {
				text = null;
			}
			controller.getState().setCurrentFilter(text);
			controller.refreshTreeContent();
		} else if (e.getSource() == panel.getClearFilterButton()) {
			panel.getFilterTextField().setText("");
			controller.getState().setCurrentFilter(null);
			controller.refreshTreeContent();
		} else if (e.getSource() == panel.getShowArtist()) {
			if (controller.getState().getViewMode() != ViewMode.ARTIST) {
				controller.getState().setViewMode(ViewMode.ARTIST);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowAlbum()) {
			if (controller.getState().getViewMode() != ViewMode.ALBUM) {
				controller.getState().setViewMode(ViewMode.ALBUM);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowGenre()) {
			if (controller.getState().getViewMode() != ViewMode.GENRE) {
				controller.getState().setViewMode(ViewMode.GENRE);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		} else if (e.getSource() == panel.getShowFolder()) {
			if (controller.getState().getViewMode() != ViewMode.FOLDER) {
				controller.getState().setViewMode(ViewMode.FOLDER);
				controller.refreshRepositoryViewTreeContent();
				controller.refreshDeviceTreeContent();
				panel.getCollapseTree().setEnabled(true);
				panel.getExpandTree().setEnabled(true);
			}
		}
	}
}
